@@ -1,6 +1,4 @@
 /*
- * $Id: cursor.c,v 1.6 2005/07/03 07:00:56 daniels Exp $
- *
  * Copyright © 2002 Keith Packard
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -34,7 +32,7 @@ XcursorCursorsCreate (Display *dpy, int size)
     cursors = malloc (sizeof (XcursorCursors) +
 		      size * sizeof (Cursor));
     if (!cursors)
-	return 0;
+	return NULL;
     cursors->ref = 1;
     cursors->dpy = dpy;
     cursors->ncursor = 0;
@@ -47,6 +45,9 @@ XcursorCursorsDestroy (XcursorCursors *cursors)
 {
     int	    n;
 
+    if (!cursors)
+      return;
+
     --cursors->ref;
     if (cursors->ref > 0)
 	return;
@@ -63,7 +64,7 @@ XcursorAnimateCreate (XcursorCursors *cursors)
 
     animate = malloc (sizeof (XcursorAnimate));
     if (!animate)
-	return 0;
+	return NULL;
     animate->cursors = cursors;
     cursors->ref++;
     animate->sequence = 0;
@@ -73,6 +74,9 @@ XcursorAnimateCreate (XcursorCursors *cursors)
 void
 XcursorAnimateDestroy (XcursorAnimate *animate)
 {
+    if (!animate)
+      return;
+
     XcursorCursorsDestroy (animate->cursors);
     free (animate);
 }
@@ -197,6 +201,9 @@ _XcursorAverageColor (XcursorPixel *pixels, int npixels)
     XcursorPixel    red, green, blue;
     int		    n = npixels;
 
+    if (n < 1)
+	return 0;
+
     blue = green = red = 0;
     while (n--)
     {
@@ -205,9 +212,7 @@ _XcursorAverageColor (XcursorPixel *pixels, int npixels)
 	green += (p >> 8) & 0xff;
 	blue += (p >> 0) & 0xff;
     }
-    if (!n)
-	return 0;
-    return (0xff << 24) | ((red/npixels) << 16) | ((green/npixels) << 8) | (blue/npixels);
+    return (0xffU << 24) | ((red/npixels) << 16) | ((green/npixels) << 8) | (blue/npixels);
 }
 
 typedef struct XcursorCoreCursor {
@@ -272,7 +277,7 @@ _XcursorHeckbertMedianCut (const XcursorImage *image, XcursorCoreCursor *core)
 	    if (green > max_green) max_green = green;
 	    if (blue < min_blue) min_blue = blue;
 	    if (blue > max_blue) max_blue = blue;
-	    p = ((0xff << 24) | (red << 16) | 
+	    p = ((0xffU << 24) | (red << 16) |
 		 (green << 8) | (blue << 0));
 	    *pc++ = p;
 	}
@@ -570,17 +575,17 @@ XcursorImageLoadCursor (Display *dpy, const XcursorImage *image)
 	ximage.red_mask = 0xff0000;
 	ximage.green_mask = 0x00ff00;
 	ximage.blue_mask = 0x0000ff;
-	ximage.obdata = 0;
+	ximage.obdata = NULL;
 	if (!XInitImage (&ximage))
 	    return None;
 	pixmap = XCreatePixmap (dpy, RootWindow (dpy, screen),
 				image->width, image->height, 32);
-	gc = XCreateGC (dpy, pixmap, 0, 0);
+	gc = XCreateGC (dpy, pixmap, 0, NULL);
 	XPutImage (dpy, pixmap, gc, &ximage, 
 		   0, 0, 0, 0, image->width, image->height);
 	XFreeGC (dpy, gc);
 	format = XRenderFindStandardFormat (dpy, PictStandardARGB32);
-	picture = XRenderCreatePicture (dpy, pixmap, format, 0, 0);
+	picture = XRenderCreatePicture (dpy, pixmap, format, 0, NULL);
 	XFreePixmap (dpy, pixmap);
 	cursor = XRenderCreateCursor (dpy, picture, 
 				      image->xhot, image->yhot);
@@ -596,13 +601,13 @@ XcursorImageLoadCursor (Display *dpy, const XcursorImage *image)
 	GC		    gc;
 	XGCValues	    gcv;
 
-	core.src_image = XCreateImage (dpy, 0, 1, ZPixmap,
-				       0, 0, image->width, image->height,
+	core.src_image = XCreateImage (dpy, NULL, 1, ZPixmap,
+				       0, NULL, image->width, image->height,
 				       32, 0);
 	core.src_image->data = Xmalloc (image->height * 
 					core.src_image->bytes_per_line);
-	core.msk_image = XCreateImage (dpy, 0, 1, ZPixmap,
-				       0, 0, image->width, image->height,
+	core.msk_image = XCreateImage (dpy, NULL, 1, ZPixmap,
+				       0, NULL, image->width, image->height,
 				       32, 0);
 	core.msk_image->data = Xmalloc (image->height * 
 					core.msk_image->bytes_per_line);
@@ -672,14 +677,14 @@ XcursorImagesLoadCursors (Display *dpy, const XcursorImages *images)
     int		    n;
 
     if (!cursors)
-	return 0;
+	return NULL;
     for (n = 0; n < images->nimage; n++)
     {
 	cursors->cursors[n] = XcursorImageLoadCursor (dpy, images->images[n]);
 	if (!cursors->cursors[n])
 	{
 	    XcursorCursorsDestroy (cursors);
-	    return 0;
+	    return NULL;
 	}
 	cursors->ncursor++;
     }
@@ -745,7 +750,7 @@ XcursorFilenameLoadCursors (Display *dpy, const char *file)
     XcursorCursors  *cursors;
     
     if (!images)
-	return 0;
+	return NULL;
     cursors = XcursorImagesLoadCursors (dpy, images);
     XcursorImagesDestroy (images);
     return cursors;
